<?
  ##########################################
## Автор: -=ШАХТЕР=-                        #                                                                                                                                                                                      ## Сайт: http://masteram.us                 #                 															                      ## ICQ  :  46-92-90                         #                 														 		           ## Версия 4.0 Лицензионная                  #
## Данная версия скрипта является ПЛАТНОЙ,  #
## вы НЕ ИМЕЕТЕ ПРАВА распрострянять данный #
##  скрипт или какие-либо части его кода... #
  #########################################
require_once"../system/start.php";
require_once"../system/sid.php";
require("../config.php");
$tyu="left";
$title="Форум";
head();

echo $fs1;
$select = @$db->sql_query ("Select * from users where id='".$usid."'");
$inf = $db->sql_fetchrow ($select);

$k_post=$db->sql_fetchfield($db->sql_query("SELECT COUNT(*) FROM `forum_message` where `login` = '".$usid."'"),0);
echo "$div1 <b>Сообщения ".$inf['user']." ($k_post)</b> $div9<br />";

if (empty($row['max'])) $row['max']=10;
$max = $row['max'];

$k_page=k_page($k_post,$max);
$page=page($k_page);
$start=$max*$page-$max;

$q=$db->sql_query("SELECT * FROM `forum_message` where `login` = '".$usid."' ORDER BY `time` DESC LIMIT $start, $max");



if ($db->sql_numrows($q)==0) {
echo "Нет сообщений\n";
}
while ($post = $db->sql_fetchrow($q))
{

$them=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_topic` WHERE `id` = '$post[topic]' LIMIT 1"));
$forum=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_sections` WHERE `id` = '$post[section]' LIMIT 1"));
$razdel=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_subfor` WHERE `id` = '$post[subfor]' LIMIT 1"));

$ank=$db->sql_fetchrow($db->sql_query("SELECT * FROM `users` WHERE `id` = $post[login] LIMIT 1"));



echo "$div2<a href='./tema/".$post['topic']."'>$them[name]</a> <a href='./tema/".$post['topic']."/end'>(".$db->sql_fetchfield($db->sql_query("SELECT COUNT(*) FROM `forum_message` WHERE `topic` = '$post[topic]'"),0).")</a>$div9\n";




echo "<a href='subfs/".$post['section']."'>$forum[name]</a> &gt; <a href='temes/".$post['subfor']."'>$razdel[name]</a><br />\n";

/*$post1=$db->sql_fetchrow($db->sql_query("SELECT * FROM `forum_message` WHERE `topic` = '$post[id]' AND `subfor` = '$razdel[id]' AND `section` = '$forum[id]' AND `login` = '$post[login]' LIMIT 1"));
$ank=$db->sql_fetchrow($db->sql_query("SELECT * FROM `users` WHERE `id` = $post[login] LIMIT 1"));
echo "Автор: <a href='".H."$ank[id]' title='Анкета \"$ank[user]\"'>$ank[user]</a> (".date("d.m в H:i", $post1['time']).")<br />\n";*/


$ank2=$db->sql_fetchrow($db->sql_query("SELECT * FROM `users` WHERE `id` = $post[login] LIMIT 1"));
echo "<a href='".H."$ank2[id]' title='Анкета \"$ank2[user]\"'>$ank2[user]</a> (".date("d.m в H:i", $post['time']).")<br />".output_text($post['msg'])."<br />\n";
echo'';
}
if ($k_page>1)str("?",$k_page,$page); // Вывод страниц

echo "<br />$div1<img src=\"../img/naz.gif\" alt=\"[N]\"/> <a href=\"./index.php?$ses\">Форум</a>$div9";
if($autorize){ echo "$div1<img src=\"../img/naz.gif\" alt=\"[N]\"/> <a href=\"../enter.php?$ses\">На Главную</a>$div9";}

foot ();
?>